//
// Project : (n)curses widget library
// File    : desktop.cc
// Purpose : definition for the desktop (background) object
//

#include "Application.hh"
#include "Desktop.hh"

namespace LWL
{

//
// constructor and destructor
//

Desktop::Desktop ( int w, int h )
        : Window( 0, 0, w, h, NULL )
{
}

Desktop::~Desktop ()
{
    while ( _windows.size() > 0 )
        delete _windows.behead();
}

//
// drawing methods
//

void
Desktop::draw ()
{
    Window::draw();

    refresh();

    DLL< Window * >::TIterator  iter = _windows.last();

    while ( ! iter.eol() )
    {
        iter()->draw();
        iter()->refresh();
        --iter;
    }// while
}

//
// window management
//

void
Desktop::add_window ( Window * win )
{
    _windows.prepend( win );

    if ( win->parent() == NULL )
        win->set_parent( this );
}

//
// event handling
//

void
Desktop::handle_event ( Event & e )
{
    //
    // first check for events which should
    // be handled by desktop
    //

    if ( e.type() == Event::EV_COMMAND )
    {
        switch ( e.command() )
        {
            case CM_EXIT   : global_app->end(); e.clear(); break;
            case CM_REDRAW : draw(); e.clear(); break;
        }// switch
    }// if

    //
    // now give event to windows
    //

    DLL< Window * >::TIterator  iter = _windows.first();
    
    while ( ! e.is_cleared() && ! iter.eol() )
    {
        iter()->handle_event( e );
        ++iter;
    }// while
}

}// namespace
