#ifndef __EVENT_HH
#define __EVENT_HH
//
// Project : LCD widget library
// File    : event.hh
// Purpose : definition for the basic event classes
//

namespace LWL
{

//
// store different events
//
class Event
{
public:
    // different event-types
    enum { EV_NOTHING, EV_KEYBOARD, EV_COMMAND };
    
protected:
    // type of event
    int    _type;

    // content of keyboard-event
    char   _keycode;

    // command event
    int    _command;
    
public:
    //
    // constructors and destructor
    //

    Event () : _type( EV_NOTHING ) {}

    ~Event () {}

    //
    // access events
    //

    // set event type and content
    Event & set_type    ( int   t ) { _type = t; return *this; }
    Event & set_keycode ( char  k ) { _type = EV_KEYBOARD; _keycode = k; return *this; }
    Event & set_command ( int   c ) { _type = EV_COMMAND;  _command = c; return *this; }
    
    // return type and content of event
    int   type    () const { return _type;    }
    char  keycode () const { return _keycode; }
    int   command () const { return _command; }

    // check if event is cleared or not
    bool is_cleared () const { return _type == EV_NOTHING; }

    // clear event
    void clear () { _type = EV_NOTHING; }
};

}// namespace

#endif  // __EVENT_HH
