#ifndef __LCD_HH
#define __LCD_HH
//
// File :    lcd.h
// Purpose : provides function to send data to lcd
//

/////////////////////////////////////////////////////////
//
// defines
//
/////////////////////////////////////////////////////////

// LED settings
#define LED_GREEN  0
#define LED_RED    1

// different buttons
#define BTN_UP      '1'
#define BTN_DOWN    '2'
#define BTN_LEFT    '0'
#define BTN_RIGHT   '4'
#define BTN_MIDDLE  '3'

// symbols
#define CHAR_ENTER        0xc4
#define CHAR_ARROW_UP     0xc5
#define CHAR_ARROW_DOWN   0xc6
#define CHAR_ARROW_RIGHT  0xc7
#define CHAR_ARROW_LEFT   0xc8
#define CHAR_LL           0xbb
#define CHAR_GG           0xcc

namespace LCD
{

// initialise LCD functions
void init ( int w, int h, const char * device );

// gather lcd status
int width ();
int height ();

// directly write to the LCD
void write ( const char * msg );

// read message from LCD with given timeout in millisec.
// - return size of message or -1 if an error occured
int read ( char * buf, int len, int timeout );

// clear LCD
void clear ();

// write char/message to LCD at position (x,y)
void putc_xy ( int x, int y, unsigned char c );
void puts_xy ( int x, int y, const char * msg );

// write changes to LCD
void flush ();

// update all positions
void invalid ();

// control cursor of LCD
void set_cursor ( int x, int y );
void no_cursor ();
void normal_cursor ();
void blink_cursor ();

// control LEDs of LCD
void led_on  ( int l );
void led_off ( int l );

// programable characters
void set_hbars ( void );
void set_vbars ( void );

}// namespace

#endif  // __LCD_HH
