#ifndef __MENU_HH
#define __MENU_HH
//
// Project : AVR LCD
// File    : Menu.hh
// Purpose : class for a menu-widget
//

#include "Window.hh"
#include "SLL.hh"

namespace LWL
{

//
// menu widget
//
class Menu : public Window
{
public:
    //
    // entry in a menu
    //

    class Entry
    {
    protected:
        // name of the entry
        char           _name[256];

        // which command to do
        int            _cmd;

        // list of submenus
        SLL< Entry * > _submenus;

        // parent menu
        Entry        * _parent;
        
    public:
        //
        // constructor
        //

        Entry ( const char * name, int cmd = -1 );

        ~Entry ();
        
        //
        // access internal data
        //

        const char * name () const { return _name; }

        int command () const { return _cmd; };

        SLL< Entry * > & submenus () { return _submenus; }

        Entry * parent () { return _parent; }

        void set_parent( Entry * p ) { _parent = p; }
        
        //
        // manage submenus
        //

        Entry * add_submenu ( Entry * submenu );
    };
    
protected:
    // chosen submenu
    unsigned        _pos;

    // main menu
    Entry         * _menu;
    
    // active/selected entry
    Entry         * _act_submenu;
    
    // rang of submenus to show
    unsigned        _lb, _ub;
    
public:
    //
    // constructor and destructor
    //

    Menu ( int x, int y, int w, int h, Window * parent = NULL );

    ~Menu ();

    //
    // event handling
    //

    virtual void handle_event ( Event & e );

    //
    // draw window content
    //
    
    virtual void draw ();

    //
    // manage submenus
    //
    
    Menu * add_entry ( Entry * entry );

    void select_active ();
    void set_active ( Entry * menu );
};

}// namespace

#endif // __MENU_HH
