//
// Project : LCD widget library
// File    : Window.cc
// Purpose : definition for the basic window widget
//

#include <string.h>

#include "LCD.hh"

#include "Window.hh"

namespace LWL
{

//
// constructor and destructor
//

Window::Window ( Window * parent )
        : _parent(parent)
{
    _x = _y = _w = _h = 0;
    _framebuffer = NULL;
}

Window::Window ( unsigned x, unsigned y, unsigned w, unsigned h, Window * parent )
        : _x(x), _y(y), _w(w), _h(h), _parent(parent)
{
    _framebuffer = NULL;
    init();
}

Window::~Window ()
{
    delete[] _framebuffer;
}

//
// event handling
//

void
Window::handle_event ( Event & e )
{
    // events are ignored by default
}
    
//
// change window parameters
//

void
Window::move ( unsigned x, unsigned y )
{
    _x = x;
    _y = y;

    draw();
    refresh();
}

void
Window::resize ( unsigned w, unsigned h )
{
    _w = w;
    _h = h;

    init();
    draw();
    refresh();
}

//
// basic draw-functionality
//

//
// print character/string at given position
//
void
Window::print_char ( unsigned x, unsigned y, char c )
{
    if ((x >= 0) && (x < _w) &&
        (y >= 0) && (y < _h))
        _framebuffer[ (y*_w) + x ] = c;
}

void
Window::print_str ( unsigned x, unsigned y, const char * s )
{
    unsigned n = strlen( s );

    for ( unsigned i = 0; i < n; i++ )
        print_char( i+x, y, s[i] );
}

//
// fill window with character
//
void
Window::fill ( char c )
{
    for ( unsigned y = 0; y < _h; y++ )
    {
        for ( unsigned x = 0; x < _w; x++ )
            print_char( x, y, c );
    }// for
}   

//
// actually draw to screen
//
void
Window::refresh ()
{
    //
    // draw content of window to LCD
    //
    
    for ( unsigned y = 0; y < _h; y++ )
    {
        for ( unsigned x = 0; x < _w; x++ )
            LCD::putc_xy( _x + x, _y + y, _framebuffer[ (y*_w) + x ] );
    }// for
}

//
// draw window content (default: fill with background)
//

void
Window::draw ()
{
    fill( ' ' );
}

//
// initialise window
//
void
Window::init ()
{
    delete[] _framebuffer;

    _framebuffer = new char[ _w * _h ];

    for ( unsigned i = 0; i < _w*_h; i++ )
        _framebuffer[i] = ' ';
}

}// namespace
