#ifndef __WINDOW_HH
#define __WINDOW_HH
//
// Project : LCD widget library
// File    : window.hh
// Purpose : definition for the basic window widget
//

#include <stdlib.h>

#include "Event.hh"

namespace LWL
{

//
// window widget, provides basic
// functionality to draw things on the screen
//
class Window
{
protected:
    // position of the window
    unsigned  _x, _y;

    // dimension of the window
    unsigned  _w, _h;

    // framebuffer to draw to
    char    * _framebuffer;

    // parent window
    Window  * _parent;
    
public:
    //
    // constructor and destructor
    //

    Window ( Window * parent = NULL );
    Window ( unsigned x, unsigned y,
             unsigned w, unsigned h,
             Window * parent = NULL );

    virtual ~Window ();

    //
    // event handling
    //

    virtual void handle_event ( Event & e );

    //
    // access/change window parameters
    //

    unsigned pos_x () const { return _x; }
    unsigned pos_y () const { return _y; }
        
    unsigned width  () const { return _w; }
    unsigned height () const { return _h; }
    
    virtual void move   ( unsigned x, unsigned y );
    virtual void resize ( unsigned w, unsigned h );

    const Window * parent () const { return _parent; }
    Window       * parent ()       { return _parent; }

    virtual void set_parent ( Window * parent ) { _parent = parent; }
    
    //
    // basic draw-functionality
    //

    // print character/string at given position
    virtual void print_char ( unsigned x, unsigned y, char c );
    virtual void print_str  ( unsigned x, unsigned y, const char * s );

    // fill window with character
    virtual void fill ( char c );
    
    // actually draw to screen
    virtual void refresh ();

    // draw window content (default: fill with spaces)
    virtual void draw ();

protected:

    // initialise window
    virtual void init ();
};

}// namespace

#endif  // __WINDOW_HH
